Re:Node.js in Flame Graphs
by andrewvc on Wednesday November 19, 2014 @05:00PM
(#8632917)
Interesting, I'm looking at it right now, and it's saying that the multiple regexes are ~ 50% slower in both chrome and firefox. Am I missing something? It looks like the single regex actually is a significant win.
It is interesting how much allocation changes things though, very cool that you made this.
Re:Node.js in Flame Graphs
by spion on Wednesday November 19, 2014 @05:05PM
(#8632960)
Yeah multiple regexes are slower, but the performance gain isn't too gigantic. If we had `regex.execIterable(string)` we could avoid allocating massive arrays and maybe get a really significant difference
It is interesting how much allocation changes things though, very cool that you made this.